## 0.0.4 (2022-01-25)


### Features

* **bert:** add tokenizer part ([997c816](https://github.com/mmmwhy/pure_attention/commit/997c8161dc55f686970606d2216ff2049c5645b3))
* **layers:** fix import for layerNorm ([eb61b31](https://github.com/mmmwhy/pure_attention/commit/eb61b313458ac18bf4b15271fee2cf7e39f8afde))
* **nlp:** init basic bert code ([f9cb13a](https://github.com/mmmwhy/pure_attention/commit/f9cb13a3e811eb8c44ba8ff1373d688311426927))



